<?php
/**
 * Inject the Bonboarding integration to the pages, if the settings are enabled and there's an API key
 */

function bonboarding_inject_script_to_public_pages()
{
    $options = get_option('bonboarding_settings');

    if (!isset($options['api_key']) || empty($options['api_key'])) {
        return;
    }
    if (!isset($options['include_on_public_pages']) || !$options['include_on_public_pages']) {
        return;
    }

    injectIntegrationScript($options['api_key']);
    injectUserIdentificationScript();
}

function bonboarding_inject_script_to_admin_pages()
{
    $options = get_option('bonboarding_settings');

    if (!isset($options['api_key']) || empty($options['api_key'])) {
        return;
    }
    if (!isset($options['include_on_admin_pages']) || !$options['include_on_admin_pages']) {
        return;
    }

    injectIntegrationScript($options['api_key']);
    injectUserIdentificationScript();
}

function injectIntegrationScript($apiKey)
{
    echo "<script data-bb-key=\"{$apiKey}\" src=\"https://go.bonboarding.com\"></script>";
}

function injectUserIdentificationScript()
{
    $current_user = wp_get_current_user();
    if (!$current_user->exists()) {
        return;
    }
    $user_id = $current_user->ID;
    $first_name = $current_user->user_firstname ? $current_user->user_firstname : $current_user->user_nicename;
    $last_name = $current_user->user_lastname ? $current_user->user_lastname : '';
    $email = $current_user->user_email;
    $sign_up_date = $current_user->user_registered;

    $identifyData = array(
        "uniqueID" => $user_id,
        "email" => $email,
        "signUpDate" => $sign_up_date,
    );

    if (!empty($first_name)) {
        $identifyData["firstName"] = $first_name;
    }

    if (!empty($last_name)) {
        $identifyData["lastName"] = $last_name;
    }

    $identifyJson = wp_json_encode($identifyData, JSON_UNESCAPED_SLASHES);

    echo "<script type='text/javascript'>
            Bonboarding.identify($identifyJson);
          </script>";
}

add_action('wp_head', 'bonboarding_inject_script_to_public_pages');
add_action('admin_head', 'bonboarding_inject_script_to_admin_pages');
